# django-rtk-magic-link

This package is an implementation of the password reset endpoints in django-rtk.

## Package specific settings

All settings are stored in `settings.DJANGO_RTK`. Below, we use
`FOO` as a shortcut for `settings.DJANGO_RTK['FOO']`.
